# Sources API Reference

## Base protocols

```{eval-rst}
.. autoclass:: xanax.sources._base.MediaSource
   :members:
```

```{eval-rst}
.. autoclass:: xanax.sources._base.AsyncMediaSource
   :members:
```
